#!/usr/bin/perl

die;

#
# dbstripleadingspace.pm
# Copyright (C) 1991-2007 by John Heidemann <johnh@isi.edu>
# $Id: 945e65d5f874859f2bfcbb03a77049cea99da2a6 $
#
# This program is distributed under terms of the GNU general
# public license, version 2.  See the file COPYING
# in $dblibdir for details.
#


package Jdb::Filter::dbstripleadingspace;

=head1 NAME
=head1 SYNOPSIS
=head1 DESCRIPTION

sub usage {
    print <<END;
usage: $0
    Strip space before the first column.

    This function is useful when pre-processing 
    incoming data before running dbcolname.

=for comment
begin_standard_jdb_options

This module also supports the standard jdb options:

=over

=item B<-d>

Enable debugging output.

=item B<-i> or B<--input> InputSource

Read from InputSource, typically a file name, or C<-> for standard input,
or (if in Perl) a IO::Handle, Jdb::IO or Jdb::BoundedQueue objects.

=item B<-o> or B<--output> OutputDestination

Write to OutputDestination, typically a file name, or C<-> for standard output,
or (if in Perl) a IO::Handle, Jdb::IO or Jdb::BoundedQueue objects.

=item B<--autorun> or B<--noautorun>

By default, programs process automatically,
but Jdb::Filter objects in Perl do not run until you invoke
the run() method.
The C<--(no)autorun> option controls that behavior within Perl.

=item B<--help>

Show help.

=item B<--man>

Show full manual.

=back

=for comment
end_standard_jdb_options


=head1 SAMPLE USAGE

=head2 Input:

 168378 /etc/passwd
 168236 /etc/passwd-
 168230 /etc/passwd.OLD
 168182 /etc/passwd~

=head2 Command:

cat raw_data | dbstripleadingspace

=head2 Output:

168378 /etc/passwd
168236 /etc/passwd-
168230 /etc/passwd.OLD
168182 /etc/passwd~
#  | /home/johnh/BIN/DB/dbstripleadingspace
END
    #' font-lock hack
    exit 1;


=head1 SEE ALSO

L<Jdb>.


=head1 CLASS FUNCTIONS

=cut

@ISA = qw(Jdb::Filter);
$VERSION = 2.0;

use strict;
use Pod::Usage;
use Carp;

use Jdb::Filter;
use Jdb::IO::Reader;
use Jdb::IO::Writer;


=head2 new

    $filter = new Jdb::Filter::dbstripleadingspace(@arguments);

Create a new dbstripleadingspace object, taking command-line arguments.

=cut

sub new ($@) {
    my $class = shift @_;
    my $self = $class->SUPER::new(@_);
    bless $self, $class;
    $self->set_defaults;
    $self->parse_options(@_);
    $self->SUPER::post_new();
    return $self;
}


=head2 set_defaults

    $filter->set_defaults();

Internal: set up defaults.

=cut

sub set_defaults ($) {
    my($self) = @_;
    $self->SUPER::set_defaults();
}

=head2 parse_options

    $filter->parse_options(@ARGV);

Internal: parse command-line arguments.

=cut

sub parse_options ($@) {
    my $self = shift @_;

    my(@argv) = @_;
    $self->get_options(
	\@argv,
 	'help|?' => sub { pod2usage(1); },
	'man' => sub { pod2usage(-verbose => 2); },
	'autorun!' => \$self->{_autorun},
	'd|debug+' => \$self->{_debug},
	'i|input=s' => sub { $self->parse_io_option('input', @_); },
	'log!' => \$self->{_logprog},
	'o|output=s' => sub { $self->parse_io_option('output', @_); },
	) or pod2usage(2);
    push (@{$self->{_argv}}, @argv);
}

=head2 setup

    $filter->setup();

Internal: setup, parse headers.

=cut

sub setup ($) {
    my($self) = @_;

    $self->finish_io_option('input', -comment_handler => $self->create_pass_comments_sub);
    my $read_fastpath_sub = $self->{_in}->fastpath_sub();

    $self->finish_io_option('output', -clone => $self->{_in});
    my $write_fastpath_sub = $self->{_out}->fastpath_sub();
}

=head2 run

    $filter->run();

Internal: run over each rows.

=cut
sub run ($) {
    my($self) = @_;
    &{$self->{_loop_sub}}();
}



use Jdb::Old;
use Jdb::DbGetopt;

my(@orig_argv) = @ARGV;
my($prog) = &progname;
my($dbopts) = new Jdb::DbGetopt("?", \@ARGV);
my($ch);
while ($dbopts->getopt) {
    $ch = $dbopts->opt;
    if (0) {
    } else {
	&usage;
    };
};
usage if ($#ARGV != -1);

while (<STDIN>) {
	if ($_ =~ /^\#/) {
		print $_;
		next;
	};

	s/^[ 	]+//;
	print $_;
};

print "#  | $prog " . join(" ", @orig_argv) . "\n";
exit 0;



=head2 finish

    $filter->finish();

Internal: write trailer.

=cut
sub finish ($) {
    my($self) = @_;

    $self->SUPER::finish();
}

=head1 AUTHOR and COPYRIGHT

Copyright (C) 1991-2007 by John Heidemann <johnh@isi.edu>

This program is distributed under terms of the GNU general
public license, version 2.  See the file COPYING
with the distribution for details.

=cut

1;
